
# TLV format:
# TAG | LENGTH | VALUE
# Header contains nested TLV triplets

TRACE_TAG_HEADER = 1

TRACE_TAG_EVENTS = 2
TRACE_TAG_FILES = 3
TRACE_TAG_METADATA = 4

HEADER_TAG_VERSION = 1
HEADER_TAG_FILES = 2
HEADER_TAG_METADATA = 3
